using UnityEngine;
using System.Collections;

//Marsfield RTS Framework
//InWorldGUIButton.cs
//
//This class is a very basic in-game button. Clicking it will cause it to be
//shrunk a little bit; giving the impression that it is being depressed. It
//also has a basic message sending function to tie its click action to an action
//of another object.
//
//-by
//1) Matt Cabanag
//2) ...
//3) ...

public class InWorldGUIButton : MonoBehaviour 
{
	public float pushButtonOffset = 0.10f;
	public KeyCode hotKey = KeyCode.Alpha1;
	public GameObject actionObject = null;
	public string actionMessage = "";
	public int actionIntParameter = 1;
	public string actionStringParameter = "";
	
	//quick access components
	private Transform qacTransform;
	private Vector3 origScale;

	// Use this for initialization
	void Start () 
	{
		qacTransform = transform;
		origScale = transform.localScale;
	}
	
	// Update is called once per frame
	void Update () 
	{
		CheckInput();
	}
	
	void OnMouseDown()
	{
		PressButton();
	}
	
	void OnMouseExit()
	{
		ReleaseButton();
	}
	
	void OnMouseUp()
	{
		ReleaseButton();
	}
	
	void CheckInput()
	{
		//check the keyboard if there's nothing going on with the mouse.
		if(!Input.GetMouseButton(0) && !Input.GetMouseButton(1) && !Input.GetMouseButton(3))
		{
			if(Input.GetKey(hotKey))
			{
				PressButton();
			}
			else
			{
				ReleaseButton();
			}
		}
	}
	
	void PressButton()
	{
		if(actionObject != null)
		{
			try
			{
				actionObject.SendMessage(actionMessage,actionIntParameter,SendMessageOptions.DontRequireReceiver);
			}
			catch
			{
				Debug.LogError("InWorldGUIButton:PressButton(int) - error sending message");
			}
			
		}
		qacTransform.localScale = origScale + new Vector3(-pushButtonOffset,-pushButtonOffset,0);
	}
	
	void ReleaseButton()
	{
		qacTransform.localScale = origScale;
	}
}
