using UnityEngine;
using System.Collections;

public class HomingDevice : MonoBehaviour 
{
	
	public TextMesh signalDisplay;
	public Transform signalBar;
	public float signalBarMaxScale = 100f;
	public Vector3 signalBarScale;
	public float beepScaleFactor = 0.5f;
	
	private float distance2Closest;
	private SignalBeacon closestBeacon;
	private SignalBeacon [] beaconList;
	private float pingStrength;
	
	//quick access components
	private Transform qacTransform;
	
	
	//UNITY CALLBACKS
	// Use this for initialization
	void Start () 
	{
		qacTransform = transform;
		
	}
	
	// Update is called once per frame
	void Update () 
	{
		
		updatePingStrength();

		if(signalDisplay != null)
		{
			signalDisplay.text = pingStrength.ToString("#.0");
		}
		
		if(closestBeacon != null && signalBar != null)
		{
			float signalStrength = closestBeacon.GetPingStrength();
			signalBar.localScale = new Vector3(signalBarMaxScale*(signalStrength/closestBeacon.pingStrengthMax)*(beepScaleFactor/distance2Closest),signalBarScale.y,signalBarScale.z);
		}
	}
	//UNITY CALLBACKS
	
	
	
	public float GetPingStrenth()
	{
		return pingStrength;
	}
	
	void updatePingStrength()
	{
		findClosestBeacon();
		
		if(closestBeacon != null)
		{
			pingStrength = closestBeacon.pingStrengthMax/(distance2Closest);
		}
	}
	
	void refreshBeaconList()
	{
		beaconList = FindObjectsOfType(typeof(SignalBeacon)) as SignalBeacon [];
	}
	
	void findClosestBeacon()
	{
		refreshBeaconList();
		
		float minDist = 1000000;
		
		foreach(SignalBeacon s in beaconList)
		{
			float dist2Bcn = Vector3.Distance(s.transform.position, qacTransform.position);
			if(dist2Bcn < minDist && s.active)
			{
				minDist = dist2Bcn;
				distance2Closest = minDist;				
				closestBeacon = s;
			}
			
		}
	}
	
}
