using UnityEngine;
using System.Collections;


public class OxygenCharacter : MonoBehaviour
{
	public float oxygenLevelMax = 30;
	public float oxygenUse = 0;
	public float touchRadius = 3;
	public float heartbeatSlowdownFactor = 0.05f;
	
	public string name;
	public string sex;
	public string age;
	public string position;
	public string crime;
	public bool alive = true;
	
	public AudioSource [] heartBeeps;
	public int [] beepThresholds;
	
	private float oxygenLevel;
	//private OxygenPlayerChar closebyPlayer;
	
	
	//quick access components
	private Transform qacTransform;
	private SignalBeacon qacSignalBeacon;
	
	//UNITY CALLBACKS
	// Use this for initialization
	void Start () 
	{
		
		oxygenLevel = oxygenLevelMax;
		qacSignalBeacon = GetComponentInChildren<SignalBeacon>();		
		qacTransform = transform;
		
		if(heartBeeps.Length > 0)
		{
			qacSignalBeacon.beepSound = heartBeeps[0];
		}
	
	}
	

	
	// Update is called once per frame
	void Update () 
	{
		oxygenLevel -= oxygenUse * Time.deltaTime;
		
		if(oxygenLevel < 0)
		{
			oxygenLevel = 0;
		}
		
		if(heartBeeps.Length > 0)
		{
			qacSignalBeacon.beepSound = heartBeeps[0];
			for(int i = 0; i < beepThresholds.Length; i++)
			{
				if(oxygenLevel <= beepThresholds[i])
				{
					//qacSignalBeacon.beepSound.Stop();
					//slowly increase the beep interval, slow the heartbeats;
					qacSignalBeacon.beepSound = heartBeeps[i+1];
					qacSignalBeacon.pingInterval += heartbeatSlowdownFactor*Time.deltaTime*Time.deltaTime;
				}
			}
		}
		
		//death!!!!!!
		if(oxygenLevel <= 0)
		{
			alive = false;
			if(qacSignalBeacon != null)
			{
				qacSignalBeacon.active = false;
			}
		}
		

		
		/*
		if(closebyPlayer != null)
		{
			if(Vector3.Distance (closebyPlayer.transform.position,transform.position) > touchRadius)
			{
				closebyPlayer = null;
			}
		}*/
	
	}
	//UNITY CALLBACKS
	
	public bool isAlive()
	{
		return alive;
	}
	
	public float OxygenGive(float oxLevel)
	{
		if(qacSignalBeacon != null)
		{
			qacSignalBeacon.pingInterval += heartbeatSlowdownFactor * Time.deltaTime;
		}
		
		if(oxygenLevel - oxLevel > 0)
		{
			oxygenLevel -= oxLevel;
			return oxLevel;
		}
		else if (oxygenLevel > 0)
		{
			oxygenLevel = 0;
			return oxygenLevel;
			
		}
		else
		{
			return 0;
		}
	}
	
	public void OxygenTake(float oxLevel)
	{
		
		if(qacSignalBeacon != null)
		{
			qacSignalBeacon.pingInterval -= heartbeatSlowdownFactor * Time.deltaTime;
		}
		
		oxygenLevel += oxLevel;
		
	}
	
	public float GetOxygenLevels()
	{
		if(oxygenLevel > 0)
		{
			return oxygenLevel;
		}
		else
		{
			return 0;
		}
	}
	
	public Transform GetTransform()
	{
		return qacTransform;
	}
}
