using UnityEngine;
using System.Collections;

public class OxygenProbe : MonoBehaviour 
{
	public OxygenPlayerChar myMaster;
	public LayerMask oxygenContainerMask;
	public OxygenProbeDisplay probeDisplay;
	public float raycastLength = 250;
	
	public float oxygenTransferRate = 0.1f;
	public KeyCode oxygenTakeKey;
	public KeyCode oxygenGiveKey;
	
	public GameObject lightBeacon;
	
	public AudioSource oxTransferLoop;
	public AudioSource deepBreath;
	public AudioSource clicks;
	public AudioSource detect;
	public AudioSource highBeep;
	public AudioSource intercomm;
	public AudioSource lowBeep;
	
	private OxygenCharacter myTarget;
	
	//quick access components
	private Transform qacTransform;
	private float scanClock = 0;
	
	//UNITY CALLBACKS
	// Use this for initialization
	void Start () 
	{
		qacTransform = transform;
		if(probeDisplay != null)
		{
			probeDisplay.myProbe = this;
		}
	}
	
	// Update is called once per frame
	void Update () 
	{
		Ray ray = new Ray();
		RaycastHit rayHit;		
		ray = new Ray(qacTransform.transform.position,qacTransform.forward);
		
		if(Physics.Raycast(ray,out rayHit,raycastLength,oxygenContainerMask.value))
		{
			myTarget = rayHit.collider.transform.root.gameObject.GetComponent<OxygenCharacter>();
			
			SignalBeacon signalBeacon = myTarget.GetComponentInChildren<SignalBeacon>();
			
			//check to see if you're in scanning range....
			if(myTarget != null)
			{
				
				if(Vector3.Distance(myTarget.GetTransform().position,qacTransform.position) > myTarget.touchRadius)
				{
					//Debug.Log ("Distance2Target: "+Vector3.Distance(myTarget.GetTransform().position,qacTransform.position));
					myTarget = null;
				}
				else
				{
					if(signalBeacon != null)
					{
						if(signalBeacon.lightBeacon == null && lightBeacon != null)
						{						
							GameObject newLightBeacon = Instantiate(lightBeacon,qacTransform.position,qacTransform.rotation) as GameObject;
							FixFollow fixFollower = newLightBeacon.transform.root.GetComponent<FixFollow>();
							
							if(fixFollower != null)
							{
								fixFollower.subject = myTarget.transform;
							}
							signalBeacon.lightBeacon = newLightBeacon;
	
						}
					}
					
					if(Input.GetKey(oxygenTakeKey))
					{
						myMaster.OxygenTake(myTarget.OxygenGive(oxygenTransferRate));
						
						if(oxTransferLoop != null && myTarget.GetOxygenLevels() > 0)
						{
							if(!oxTransferLoop.isPlaying)
							{
								oxTransferLoop.Play ();
							}
						}
					}
					
					if(Input.GetKey(oxygenGiveKey) && myMaster.GetOxygenLevels() > 0)
					{
						myTarget.OxygenTake (myMaster.OxygenGive (oxygenTransferRate));
						
						if(oxTransferLoop != null)
						{
							if(!oxTransferLoop.isPlaying)
							{
								oxTransferLoop.Play ();
							}
						}
					}
					
					if(scanClock <=0)
					{
						if(!intercomm.isPlaying)
						{
							intercomm.Play ();
						}
					}
					
					
					scanClock = 2;
				}
			}

			
		}
		else
		{
			//waiting for scanclock to tick down gives a delay
			//for the information screen to stay up.
			if(scanClock <= 0)
			{
				myTarget = null;
			}
		}
		
		if(scanClock > 0)
		{
			scanClock -= Time.deltaTime;
		}
		else
		{
			scanClock = 0;
		}
		
		
	}
	//UNITY CALLBACKS
	
	public OxygenCharacter GetMyTarget()
	{
		return myTarget;
	}
				
	public Transform GetTransform()
	{
		return qacTransform;
	}
}
