using UnityEngine;
using System.Collections;

public class SignalBeacon : MonoBehaviour 
{
	public float pingStrengthMax = 10;
	public bool active = true;
	public float pingInterval = 1.5f;
	public float pingFalloff = 0.5f;
	public GameObject lightBeacon;
	
	public AudioSource beepSound;
	public AudioSource deathSound;
	
	private float pingClock = 0;
	private float pingStrength = 0;
	
	private Blink2Mat flasher;
	private bool tagSwitch = false;
	private bool deathSoundSwitch = false;
	
	//UNITY CALLBACKS
	// Use this for initialization
	void Start () 
	{
		pingStrength = pingStrengthMax;
		pingClock = Random.Range(0,pingInterval*0.5f);
	}
	
	// Update is called once per frame
	void Update () 
	{
		if(active)
		{
			if(pingClock > 0)
			{
				pingClock -=  Time.deltaTime;
				
				if(pingStrength - pingFalloff > 0)
				{
					pingStrength -= pingFalloff;
				}
				else
				{
					pingStrength = 0;
				}
			}
			else
			{
				pingClock = pingInterval;
				pingStrength = pingStrengthMax;
				
				if(beepSound != null)
				{
					if(!beepSound.isPlaying)
					{
						beepSound.Play();
					}
				}
				
				
				if(lightBeacon != null)
				{
					tagSwitch = true;
					
					if(flasher == null)
					{
						flasher = lightBeacon.GetComponentInChildren<Blink2Mat>();
					}
					
					flasher.Flash();
					
				}
			}
		}
		else
		{
			//inactive pinger. everything down to zero!
			if(lightBeacon != null)
			{
				lightBeacon.SetActive(false);
			}
			
			if(!deathSoundSwitch)
			{
				if(deathSound != null)
				{
					if(!deathSound.isPlaying)
					{
						deathSound.Play();
					}
				}
				deathSoundSwitch = true;
			}
			
			pingStrength = 0;
		}
	}
	//UNITY CALLBACKS
	
	public float GetPingStrength()
	{
		return pingStrength;
	}
	
	public bool TagStatus()
	{
		return tagSwitch;
	}
}
